@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-10-11'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-10-21'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -153,12 +153,21 @@ sub datapack_modules {
             seek DATA, $data_pos, 0;
 
             my $fh = \*DATA;
-my $header_line = <$fh>;
-        defined($header_line)
-            or die "Unexpected end of data section while reading header line";
-        chomp($header_line);
-        $header_line eq 'Data::Section::Seekable v1'
-            or die "Invalid header, must be 'Data::Section::Seekable v1' (got: $header_line)";
+
+        my $header_line;
+        my $header_found;
+        while (1) {
+            my $header_line = <$fh>;
+            defined($header_line)
+                or die "Unexpected end of data section while reading header line";
+            chomp($header_line);
+            if ($header_line eq 'Data::Section::Seekable v1') {
+                $header_found++;
+                last;
+            }
+        }
+        die "Can't find header 'Data::Section::Seekable v1'"
+            unless $header_found;
 
         my %toc;
         my $i = 0;
@@ -176,6 +185,7 @@ my $header_line = <$fh>;
         my $pos = tell $fh;
         $toc{$_}[0] += $pos for keys %toc;
 
+
             \%toc;
         };
         if ($toc->{$_[1]}) {
@@ -244,7 +254,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.12 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-10-11.
+This document describes version 0.13 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-10-21.
 
 =head1 SEE ALSO
 
